package fr.benjaminprevot.itext;

import java.io.BufferedReader;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.FileReader;
import java.io.IOException;
import java.io.OutputStream;
import java.util.ArrayList;
import java.util.List;

import com.itextpdf.text.Document;
import com.itextpdf.text.DocumentException;
import com.itextpdf.text.PageSize;
import com.itextpdf.text.Paragraph;
import com.itextpdf.text.pdf.MultiColumnText;
import com.itextpdf.text.pdf.PdfWriter;

/**
 * @author Benjamin PREVOT
 * @created 19 juin 2010
 */
public class Columns {
	
	private String pathname;
	private String filename;
	
	/**
	 * Constructeur
	 */
	public Columns(String pathname, String filename) {
		this.pathname = pathname;
		this.filename = filename;
	}
	
	/**
	 * Charge le texte  afficher  partir d'un fichier
	 * @param pathname Chemin complet vers le fichier
	 * @return Une liste de paragraphes  afficher
	 * @throws FileNotFoundException Si le fichier n'existe pas
	 * @throws IOException Si une exception I/O est gnre
	 */
	public List<String> getText(
			String pathname)
	throws FileNotFoundException, IOException {
		// Fichier contenant le texte
		File file = new File(pathname);
		
		// Reader pour lire le contenu du fichier
		BufferedReader reader = new BufferedReader(new FileReader(file));
		
		// Initialisation de la liste
		List<String> list = new ArrayList<String>();
		
		// Lecture du fichier
		while (reader.ready()) {
			list.add(reader.readLine());
		}
		
		// Retour du contenu
		return list;
	}
	
	/**
	 * Cration du fichier PDF
	 * @throws DocumentException Si une exception est gnre dans le Document
	 * @throws FileNotFoundException Si le fichier n'est pas trouv
	 * @throws IOException Si une exception I/O est gnre
	 */
	public void generate() throws DocumentException, FileNotFoundException, IOException {
		// Fichier PDF
		File file = new File(filename);
		
		// Si le fichier existe dj, il est supprim
		if (file.exists()) { 
			file.delete();
		}
		
		// Flux de sortie
		OutputStream os = new FileOutputStream(file);
		
		// Cration du document iText
		Document document = new Document(PageSize.A4, 20, 20, 20, 20);
		
		// Lien entre le document et le flux de sortie
		PdfWriter.getInstance(document, os);
		
		// Ouverture du docuement pour criture
		document.open();
		
		// Cration d'un object MultiColumnText permettant de grer l'affichage par colonne
		MultiColumnText mct = new MultiColumnText();
		
		// Dfinition des colonnes
		mct.addRegularColumns(document.left(), document.right(), 10f, 3);
		
		// Affichage des paragraphes
		List<String> list = getText(pathname);
		
		for (String s : list) {
			mct.addElement(new Paragraph(s));
		}
		
		document.add(mct);
		
		// Fermeture du document et enregistrement dans le fichier columns.pdf
		document.close();
	}
	
	public static void main(String[] args) throws Exception {
		Columns columns = new Columns("C:/lipsum.txt", "C:/columns.pdf");
		columns.generate();
	}
	
}
